@@ -404,17 +404,18 @@ bool SPConfig::instantiate(const char* config, bool rethrow)
 #ifdef _DEBUG
     NDC ndc("instantiate");
 #endif
+
     if (!config)
         config = getenv("SHIBSP_CONFIG");
-    if (!config)
+    if (!config) {
         config = SHIBSP_CONFIG;
+    }
     try {
         xercesc::DOMDocument* dummydoc;
         if (*config == '"' || *config == '\'') {
             throw ConfigurationException("The value of SHIBSP_CONFIG started with a quote.");
         }
         else if (*config != '<') {
-
             // Mock up some XML.
             string resolved(config);
             stringstream snippet;
@@ -424,7 +425,7 @@ bool SPConfig::instantiate(const char* config, bool rethrow)
                 << "' validate='1'/>";
             dummydoc = XMLToolingConfig::getConfig().getParser().parse(snippet);
             XercesJanitor<xercesc::DOMDocument> docjanitor(dummydoc);
-            setServiceProvider(ServiceProviderManager.newPlugin(XML_SERVICE_PROVIDER, dummydoc->getDocumentElement()));
+            setServiceProvider(ServiceProviderManager.newPlugin(XML_SERVICE_PROVIDER, dummydoc->getDocumentElement(), true));
             if (m_configDoc)
                 m_configDoc->release();
             m_configDoc = docjanitor.release();
@@ -436,7 +437,7 @@ bool SPConfig::instantiate(const char* config, bool rethrow)
             static const XMLCh _type[] = UNICODE_LITERAL_4(t,y,p,e);
             auto_ptr_char type(dummydoc->getDocumentElement()->getAttributeNS(nullptr,_type));
             if (type.get() && *type.get())
-                setServiceProvider(ServiceProviderManager.newPlugin(type.get(), dummydoc->getDocumentElement()));
+                setServiceProvider(ServiceProviderManager.newPlugin(type.get(), dummydoc->getDocumentElement(), true));
             else
                 throw ConfigurationException("The supplied XML bootstrapping configuration did not include a type attribute.");
             if (m_configDoc)
@@ -447,10 +448,13 @@ bool SPConfig::instantiate(const char* config, bool rethrow)
         getServiceProvider()->init();
         return true;
     }
-    catch (exception& ex) {
-        if (rethrow)
+    catch (const std::exception& ex) {
+        if (rethrow) {
             throw;
-        Category::getInstance(SHIBSP_LOGCAT ".Config").fatal("caught exception while loading configuration: %s", ex.what());
+        }
+        else {
+            Category::getInstance(SHIBSP_LOGCAT ".Config").fatal("caught exception while loading configuration: %s", ex.what());
+        }
     }
     return false;
 }
@@ -498,3 +502,55 @@ void SPInternalConfig::term()
 
     SPConfig::term();
 }
+
+#ifndef SHIBSP_LITE
+bool SPConfig::shouldSignOrEncrypt(const char* setting, const char* endpoint, bool isUserAgentPresent)
+{
+    if (setting && (!strcmp(setting, "true") || !strcmp(setting, isUserAgentPresent ? "front" : "back"))) {
+        return true;
+    }
+    else if (!setting || !strcmp(setting, "conditional")) {
+        if (isUserAgentPresent || !endpoint) {
+            return true;
+        }
+
+        // Conditional on the back channel means to sign if TLS isn't used or if on port 443.
+        // This compensates for the fact that using the default TLS port likely implies no use
+        // of client TLS by the server, allowing us to migrate off of the back channel with no
+        // configuration changes.
+#ifdef HAVE_STRCASECMP
+        if (strncasecmp(endpoint, "http://", 7) == 0) {
+#else
+        if (strnicmp(endpoint, "http://", 7) == 0) {
+#endif
+            return true;
+        }
+#ifdef HAVE_STRCASECMP
+        else if (strncasecmp(endpoint, "https://", 8) == 0) {
+#else
+        else if (strnicmp(endpoint, "https://", 8) == 0) {
+#endif
+            const char* colon = strchr(endpoint + 8, ':');
+            if (colon) {
+#ifdef HAVE_STRCASECMP
+                if (strncasecmp(colon, ":443/", 5) == 0) {
+#else
+                if (strnicmp(colon, ":443/", 5) == 0) {
+#endif
+                    return true;
+                }
+            }
+            else {
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+#endif
+
+Category& SPConfig::deprecation() const
+{
+    return Category::getInstance(SHIBSP_LOGCAT".DEPRECATION");
+}
