@@ -317,7 +317,7 @@ Override::Override(bool unicodeAware, const DOMElement* e, Category& log, const
             if (path && path->hasAttributeNS(nullptr, ignoreCase)) {
                 // In this one case, we've left ignoreCase reversed (true means case sensitive, false means insensitive).
                 // This was to protect people who followed the security advisory for SSPCPP-691 and reversed their setting.
-                log.error("DEPRECATED: ignoreCase attribute in PathRegex element will be interpreted backwards. Replace with caseSensitive");
+                SPConfig::getConfig().deprecation().error("ignoreCase attribute in PathRegex element will be interpreted backwards. Replace with caseSensitive");
                 caseSensitive = XMLHelper::getAttrBool(path, true, ignoreCase);
             } else {
                 // If the old ignoreCase setting isn't set, then we just process normally.
@@ -410,19 +410,26 @@ const Override* Override::locate(const HTTPRequest& request) const
 
     // Now we copy the path, chop the query string, and possibly lower case it.
     string::size_type sep = dup.find('?');
-    if (sep != string::npos)
+    if (sep != string::npos) {
         dup = dup.substr(0, sep);
-    if (!m_unicodeAware) {
-        to_lower(dup);
     }
 
     // Default is for the current object to provide settings.
     const Override* o = this;
 
+    // Reset the path pointer to the beginning of the decoded copy.
+    path = dup.c_str();
+
     // Tokenize the path by segment and try and map each segment.
     tokenizer< char_separator<char> > tokens(dup, char_separator<char>("/"));
     for (tokenizer< char_separator<char> >::iterator token = tokens.begin(); token != tokens.end(); ++token) {
-        map< string,boost::shared_ptr<Override> >::const_iterator i = o->m_map.find(*token);
+
+        string tokendup(*token);
+        if (!m_unicodeAware) {
+            to_lower(tokendup);
+        }
+
+        map< string,boost::shared_ptr<Override> >::const_iterator i = o->m_map.find(tokendup);
         if (i == o->m_map.end())
             break;  // Once there's no match, we've consumed as much of the path as possible here.
         // We found a match, so reset the settings pointer.
@@ -430,21 +437,16 @@ const Override* Override::locate(const HTTPRequest& request) const
 
         // We descended a step down the path, so we need to advance the original
         // parameter for the regex step later.
-        path += token->length();
+        path += tokendup.length();
         if (*path == '/')
             path++;
     }
 
     // If there's anything left, we try for a regex match on the rest of the path minus the query string.
     if (*path) {
-        string path2(path);
-        sep = path2.find('?');
-        if (sep != string::npos)
-            path2 = path2.substr(0, sep);
-
         for (vector< pair< boost::shared_ptr<RegularExpression>,boost::shared_ptr<Override> > >::const_iterator re = o->m_regexps.begin(); re != o->m_regexps.end(); ++re) {
             try {
-                if (re->first->matches(path2.c_str())) {
+                if (re->first->matches(path)) {
                     o = re->second.get();
                     break;
                 }
@@ -507,7 +509,7 @@ XMLRequestMapperImpl::XMLRequestMapperImpl(const DOMElement* e, Category& log) :
     }
 
     if (XMLString::equals(e->getNamespaceURI(), shibspconstants::SHIB2SPCONFIG_NS)) {
-        log.warn("DEPRECATED: legacy 2.0 configuration, support will be removed from a future version of the software");
+        SPConfig::getConfig().deprecation().warn("legacy V2 configuration");
     }
 
     // Load the property set.
